@@ -397,6 +397,8 @@ class Arena():
 
             for file in files:
                 with open(f"{folder_name}/file_vault/[{file.number}] {file.title}.{file.format}", "w+") as f:
+                    f.write(file.content)
+                    f.truncate()
 
 
         #Item
